use strict; use warnings;
package Lingy::Lang::Var;

use Lingy::Common;
use base SCALARTYPE;

1;
